<?php 
	$user = cmsUser::getInstance(); 
	$options = $item['places-options'];
	$this->addCSS($this->getStylesFileName('places'));
	$this->addJS('templates/default/js/maps/systems/'.$options['system'].'.js');
	$this->addJS('templates/default/js/maps/item.js');		
	$this->addMenuItems('item-menu', $item['menu-items']);	

	$is_can_review = $options['reviews_on'] &&
					 cmsUser::isAllowed($ctype['name'], 'add_reviews') &&
					 !cmsUser::isPermittedLimitReached($ctype['name'], 'max_reviews', $item['user_reviews_count']) &&
					 ($user->id != $item['user_id']);
	
	$is_can_add_news = $options['news_on'] &&
						(
							cmsUser::isAllowed($ctype['name'], 'add_news', 'all_places') || 
							(cmsUser::isAllowed($ctype['name'], 'add_news', 'own_places') && $item['user_id'] == $user->id)
						) &&
						!cmsUser::isPermittedLimitReached($ctype['name'], 'max_news', $item['user_news_month_count']);
	
	$is_can_add_events = $options['events_on'] &&
						(
							cmsUser::isAllowed($ctype['name'], 'add_events', 'all_places') || 
							(cmsUser::isAllowed($ctype['name'], 'add_events', 'own_places') && $item['user_id'] == $user->id)
						) &&
						!cmsUser::isPermittedLimitReached($ctype['name'], 'max_events', $item['user_events_month_count']);
		
	if ($is_can_review) {	
		$this->addToolButton(array(
			'class' => 'add',
			'title' => LANG_PLACES_REVIEW_ADD,
			'href'  => href_to('places', 'add_review', $item['id'])
		));	
	}
		
	if ($is_can_add_news) {	
		$this->addToolButton(array(
			'class' => 'add',
			'title' => LANG_PLACES_NEWS_ADD,
			'href'  => href_to('places', 'add_news', $item['id'])
		));	
	}
	
		
	if ($is_can_add_events) {	
		$this->addToolButton(array(
			'class' => 'add',
			'title' => LANG_PLACES_EVENTS_ADD,
			'href'  => href_to('places', 'add_event', $item['id'])
		));	
	}
	
	if ($user->is_admin){
		$this->addToolButton(array(
			'class' => 'user_add',
			'title' => LANG_PLACES_CHANGE_OWNER,
			'href'  => href_to('places', 'owner', $item['id'])
		));			
	}
    
    $markers = $item['markers'];
    $first_marker = count($markers) ? array_shift($markers) : array('id'=>false);
    unset($markers);
	
?>

<?php if ($fields['title']['is_in_item']){ ?>
    <h1>
        <?php if ($item['parent_id']){ ?>
            <div class="parent_title">
                <a href="<?php echo href_to($item['parent_url']); ?>"><?php html($item['parent_title']); ?></a> &rarr;
            </div>
        <?php } ?>
        <?php html($item['title']); ?>
        <?php if ($item['is_private']) { ?>
            <span class="is_private" title="<?php html(LANG_PRIVACY_PRIVATE); ?>"></span>
        <?php } ?>
    </h1>
    <?php unset($fields['title']); ?>
<?php } ?>

<?php if ($item['menu-items']){ ?>
	<div id="maps-item-menu">
		<div class="tabs-menu">
			<?php $this->menu('item-menu'); ?>
		</div>
	</div>
<?php } ?>

<?php if ($options['reviews_on'] && $options['reviews_rating']) { ?>
<div id="maps-item-rating">
	<div class="score total">
		<div class="legend"><?php echo LANG_RATING; ?></div>
		<?php $this->renderChild('../places/stars', array('value' => $item['rating_avg'], 'class'=>'red')); ?>	
	</div>
	<?php for($r=1; $r<=3; $r++) { ?>
		<?php if (empty($item['rating-criteria'][$r])) { continue; } ?>
		<div class="score rating-<?php echo $r; ?>">
			<div class="legend"><?php echo $item['rating-criteria'][$r]; ?></div>
			<?php $this->renderChild('../places/stars', array('value' => $item['rating'.$r])); ?>	
		</div>
	<?php } ?>
</div>
<?php } ?>

<div class="content_item <?php echo $ctype['name']; ?>_item">

    <?php foreach($fields as $name=>$field){ ?>

        <?php if (!$field['is_in_item']) { continue; } ?>
        <?php if ($field['is_system']) { continue; } ?>
        <?php if (empty($item[$field['name']])) { continue; } ?>
        <?php if ($field['groups_read'] && !$user->isInGroups($field['groups_read'])) { continue; } ?>

        <?php
            if (!isset($field['options']['label_in_item'])) {
                $label_pos = 'none';
            } else {
                $label_pos = $field['options']['label_in_item'];
            }
        ?>

        <div class="field ft_<?php echo $field['type']; ?> f_<?php echo $field['name']; ?>">

            <?php if ($label_pos != 'none'){ ?>
                <div class="title_<?php echo $label_pos; ?>"><?php html($field['title']); ?>: </div>
            <?php } ?>

            <div class="value">

                <?php
                    echo $field['html'];
                ?>

            </div>

        </div>

    <?php } ?>

    <?php if ($props && $props_values) { ?>
        <?php
            $props_fields = $this->controller->getPropsFields($props);
            $props_fieldsets = cmsForm::mapFieldsToFieldsets($props);
        ?>
        <div class="content_item_props <?php echo $ctype['name']; ?>_item_props">
            <table>
                <tbody>
                    <?php foreach($props_fieldsets as $fieldset){ ?>
                        <?php if ($fieldset['title']){ ?>
                            <tr>
                                <td class="heading" colspan="2"><?php html($fieldset['title']); ?></td>
                            </tr>
                        <?php } ?>
                        <?php if ($fieldset['fields']){ ?>
                            <?php foreach($fieldset['fields'] as $prop){ ?>
                                <?php if (isset($props_values[$prop['id']])) { ?>
                                <?php $prop_field = $props_fields[$prop['id']]; ?>
                                    <tr>
                                        <td class="title"><?php html($prop['title']); ?></td>
                                        <td class="value">
                                            <?php echo $prop_field->parse($props_values[$prop['id']]); ?>
                                        </td>
                                    </tr>
                                <?php } ?>
                            <?php } ?>
                        <?php } ?>
                    <?php } ?>
                </tbody>
            </table>
        </div>
    <?php } ?>

	<?php if ($item['markers']) { ?>
	
		<div class="gui-panel maps-item-contacts">
			
			<div class="maps-mini-map">
				<div id="map-canvas"></div>
                <?php if ($options['is_embed']){ ?>
                    <div class="embed-link">
                        <?php $embed_url = href_to($ctype['name'], 'embed_code', $item['id']); ?>
                        <a data-href="<?php echo $embed_url; ?>" href="<?php if (isset($first_marker['id'])){ echo $embed_url .'/' . $first_marker['id']; } ?>" class="ajax-modal" title="<?php echo LANG_PLACES_EMBED; ?>"><?php echo LANG_PLACES_EMBED; ?></a>
                    </div>
                <?php } ?>
			</div>			
			
			<div class="maps-addrs-list">	
				<h2><?php echo LANG_PLACES_ITEM_ADDR_BLOCK; ?></h2>
				<ul class="addresses">
					<?php foreach($item['markers'] as $marker) { ?>
						<li class="marker-<?php echo $marker['id']; ?>">
							<a href="#<?php echo $marker['id']; ?>" class="ajaxlink addr" data-lat="<?php echo nf($marker['lat'], 4); ?>" data-lng="<?php echo nf($marker['lng'], 4); ?>" data-id="<?php echo $marker['id']; ?>"><?php echo $marker['address']; ?></a>
							<?php if ($options['reviews_on']){ ?>
								<div class="reviews">					
									<?php if ($options['reviews_rating']){ ?>
										<?php $this->renderChild('../places/stars', array('value' => $marker['rating_avg'], 'show_value'=>false, 'class'=>'small')); ?>	
									<?php } ?>
									<a href="<?php echo href_to('places', 'reviews', array($item['id'])) . "?addr_id={$marker['id']}"; ?>"><?php echo html_spellcount($marker['reviews_count'], LANG_PLACES_REVIEW_SPELLCOUNT); ?></a>
								</div>
							<?php } ?>							
							<div class="contacts">
								<?php if ($marker['contacts']){ ?>
									<?php $this->renderChild('../places/contacts', array('contacts'=>$marker['contacts'])); ?>
								<?php } ?>
							</div>
						</li>
					<?php } ?>
				</ul>
				<?php if (count($item['markers'])>1) {?>
					<?php $scount = html_spellcount(count($item['markers'])-1, LANG_PLACES_ITEM_ADDR_SPELLCOUNT); ?>
					<a href="#show-more" class="show-more-addrs ajaxlink"><?php printf(LANG_PLACES_ITEM_ADDR_MORE, $scount); ?></a>
				<?php } ?>
			</div>
			
			<script>				
				icms.mapsItem.init('map-canvas', {
					zoom: <?php echo $options['mm_zoom'] + 1; ?>,
					min_zoom: <?php echo $options['mm_min_zoom'] + 1; ?>,
					max_zoom: <?php echo $options['mm_max_zoom'] + 1; ?>,
					icon: '<?php echo $first_marker['icon'] ? $first_marker['icon'] : 'default.png'; ?>',
					icons_url: '<?php echo cmsConfig::get('upload_host') . '/markers'; ?>',
					map_type: '<?php echo $options['mm_map_type']; ?>',
					title: '<?php echo $item['title']; ?>',
					<?php if (!empty($options['key'])) { ?>
						api_key: '<?php echo $options['key']; ?>'
					<?php } ?>					
				});
			</script>
			
		</div>
	
	<?php } ?>	
	
    <?php
        $hooks_html = cmsEventsManager::hookAll("content_{$ctype['name']}_item_html", $item);
        if ($hooks_html) { echo html_each($hooks_html); }
    ?>

    <?php
        $is_tags = $ctype['is_tags'] &&
                   !empty($ctype['options']['is_tags_in_item']) &&
                   $item['tags'];
    ?>

    <?php if ($is_tags){ ?>
        <div class="tags_bar">
            <?php echo html_tags_bar($item['tags']); ?>
        </div>
    <?php } ?>

    <?php
        $show_bar = $ctype['is_rating'] ||
                    $fields['date_pub']['is_in_item'] ||
                    $fields['user']['is_in_item'] ||
					!empty($ctype['options']['hits_on']) || 
					!$item['is_pub'] || 
                    !$item['is_approved'];
    ?>

    <?php if ($ctype['item_append_html']){ ?>
        <div class="append_html"><?php echo $ctype['item_append_html']; ?></div>
    <?php } ?>

    <?php if ($show_bar){ ?>
        <div class="info_bar">
            <?php if ($ctype['is_rating']){ ?>
                <div class="bar_item bi_rating">
                    <?php echo $item['rating_widget']; ?>
                </div>
            <?php } ?>
            <?php if ($fields['date_pub']['is_in_item']){ ?>
                <div class="bar_item bi_date_pub" title="<?php html( $fields['date_pub']['title'] ); ?>">
                    <?php echo $fields['date_pub']['html']; ?>
                </div>
            <?php } ?>
            <?php if (!$item['is_pub']){ ?>
                <div class="bar_item bi_not_pub">
                    <?php echo LANG_CONTENT_NOT_IS_PUB; ?>
                </div>
            <?php } ?>			
            <?php if (!empty($ctype['options']['hits_on'])){ ?>
                <div class="bar_item bi_hits" title="<?php echo LANG_HITS; ?>">
                    <?php echo $item['hits_count']; ?>
                </div>
            <?php } ?>			
            <?php if ($fields['user']['is_in_item']){ ?>
                <div class="bar_item bi_user" title="<?php html( $fields['user']['title'] ); ?>">
                    <?php echo $fields['user']['html']; ?>
                </div>
                <?php if (!empty($item['folder_title'])){ ?>
                    <div class="bar_item bi_folder">
                        <a href="<?php echo href_to('users', $item['user']['id'], array('content', $ctype['name'], $item['folder_id'])); ?>"><?php echo $item['folder_title']; ?></a>
                    </div>
                <?php } ?>
            <?php } ?>
            <div class="bar_item bi_share">
                <div class="share" style="margin:-4px">
                    <script type="text/javascript" src="//yandex.st/share/share.js" charset="utf-8"></script>
                    <div class="yashare-auto-init" data-yashareL10n="ru" data-yashareType="none" data-yashareQuickServices="yaru,vkontakte,facebook,twitter,odnoklassniki,moimir,lj,gplus"></div>
                </div>
            </div>
            <?php if (!$item['is_approved']){ ?>
                <div class="bar_item bi_not_approved">
                    <?php echo LANG_CONTENT_NOT_APPROVED; ?>
                </div>
            <?php } ?>
        </div>
    <?php } ?>

</div>
